<?php

/*
   File: closest-stops.php
   Returns the closest stops to a particular lat long.  Input is from POST,
   variables 'lat' and 'long', and output is json.
*/

include_once('./include/config.php');
include_once('./include/database.php');

/*
   Function: calculate_distance
   Returns the distance between two lat long values.

   Parameters:
      lat1, lon1  -  *float* first set of lat/long values
      lat2, lon2  -  *float* second set of lat/long values

   Returns:
      Distance between the two lat/lon values.
*/
function calculate_distance($lat1, $lon1, $lat2, $lon2)
{
   $pk = (180/3.14169);
   $a1 = $lat1/$pk;
   $a2 = $lon1/$pk;
   $b1 = $lat2/$pk;
   $b2 = $lon2/$pk;

   $t1 = cos($a1)*cos($a2) * cos($b1)*cos($b2);
   $t2 = cos($a1)*sin($a2) * cos($b1)*sin($b2);
   $t3 = sin($a1)*sin($b1);

   $tt = acos($t1+$t2+$t3);
   
   return 6366000*$tt;
}

if (isset($_GET['agency'])) $agency = $_GET['agency']; else $agency = 'rutgers';

if (isset($_POST['lat'])) $lat = $_POST['lat']; else $lat = $_GET['lat'];
if (isset($_POST['lon'])) $lon = $_POST['lon']; else $lon = $_GET['lon'];
if (isset($_POST['limit'])) $limit = $_POST['limit']; else $limit = $_GET['limit'];

if (is_null($lat) || is_null($lon) || is_null($limit))
   die('ERROR: Not enough parameters, you must provide lat, lon, and limit.');

$results = db_query('SELECT ref, stopid, stopname, AsText(stoploc), GLength( LineString( stoploc, GeomFromText("POINT (%s %s)") )) AS howFar FROM stops WHERE agency="%s" ORDER BY howFar ASC LIMIT %s', $lat, $lon, $agency, $limit);

for($i = 0; $i < count($results); $i++)
{
   $results[$i]['AsText(stoploc)'] = preg_replace('/[POINT()]/', '', $results[$i]['AsText(stoploc)']);
   list($results[$i]['lat'], $results[$i]['lon']) = split(' ', $results[$i]['AsText(stoploc)']);
   $results[$i]['distance'] = calculate_distance($lat, $lon, $results[$i]['lat'], $results[$i]['lon']);
   unset($results[$i]['AsText(stoploc)']);
   unset($results[$i]['howFar']);
}

echo json_encode($results);
?>
